@@ -1,6 +1,6 @@
 package Class::Meta::AccessorBuilder::Affordance;
 
-# $Id: Affordance.pm,v 1.8 2004/01/09 03:50:22 david Exp $
+# $Id: Affordance.pm,v 1.10 2004/01/10 01:58:11 david Exp $
 
 =head1 NAME
 
@@ -65,7 +65,7 @@ contexts, but may do so in a future release.
 
 use strict;
 use Class::Meta;
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 sub build_attr_get {
     UNIVERSAL::can($_[0]->package, 'get_' . $_[0]->name);
@@ -121,6 +121,15 @@ sub build {
 1;
 __END__
 
+=head1 DISTRIBUTION INFORMATION
+
+This file was packaged with the Class-Meta-0.11 distribution.
+
+=head1 BUGS
+
+Please report all bugs via the CPAN Request Tracker at
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Class-Meta>.
+
 =head1 AUTHOR
 
 David Wheeler <david@kineticode.com>
